import {
  GanttComponent,
  Inject,
  Edit,
  Selection,
  Filter,
  Toolbar,
  CriticalPath,
  ContextMenu,
  ExcelExport,
} from "@syncfusion/ej2-react-gantt"

const editSettings = {
  allowAdding: true,
  allowEditing: true,
  allowDeleting: true,
  showDeleteConfirmDialog: true,
  allowTaskbarEditing: true, //Permite editar directamente resizeando la tarea
  mode: "Auto",
}

const toolbar = [
  "Edit",
  "Add",
  "Update",
  "Delete",
  "Cancel",
  "ExpandAll",
  "CollapseAll",
  "CriticalPath",
  "ExcelExport",
  "ZoomIn",
  "ZoomOut",
  "ZoomToFit",
]

const services = [
  Edit,
  Selection,
  Filter,
  Toolbar,
  CriticalPath,
  ContextMenu,
  ExcelExport,
]

let ganttInstance

export default function Gantt(props) {
  const { data, dataFields, resources, resourceFields, style } = props

  function actionBegin(args) {
    if (args.requestType == "validateLinkedTask") {
      args.validateMode.preserveLinkWithEditing = false //Disable to force dialog
    }
  }
  function onToolBarClick(args) {
    if (args.item.id.includes("excelexport")) {
      ganttInstance.excelExport()
    }
  }

  return (
    <GanttComponent
      ref={(gantt) => (ganttInstance = gantt)}
      dataSource={data}
      taskFields={dataFields}
      editSettings={editSettings}
      allowSelection={true}
      //allowFiltering={true}
      renderBaseline={true}
      baselineColor="#ffe599"
      resourceFields={resourceFields}
      resources={resources}
      toolbar={toolbar}
      enableContextMenu={true}
      actionBegin={actionBegin.bind(this)}
      locale={"es-AR"}
      style={style}
      height="450px"
      splitterSettings={{
        columnIndex: 3,
      }}
      allowExcelExport={true}
      toolbarClick={onToolBarClick.bind(this)}
    >
      <Inject services={services} />
      {props.children}
    </GanttComponent>
  )
}
